@@ -13,6 +13,7 @@ from sys import platform
 
 from embedops_cli.utilities import quote_str_for_platform
 from embedops_cli import environment_utilities as envutil
+from embedops_cli.embedops_authorization import get_registry_token
 from .eo_types import (
     NoDockerContainerException,
     InvalidDockerContainerException,
@@ -81,14 +82,25 @@ def docker_run(run_context: LocalRunContext):
 
     _logger.debug(f"Script as string: {script}")
 
+    # add AWS credential for DinD
+    aws_token_data = get_registry_token()
+    aws_token_data["AWS_ACCESS_KEY_ID"] = aws_token_data.pop("registry_token_id")
+    aws_token_data["AWS_SECRET_ACCESS_KEY"] = aws_token_data.pop(
+        "registry_token_secret"
+    )
+    run_context.variables.update(aws_token_data)
+
     envutil.create_job_env_file(run_context.variables)
 
     dockercmd = ["docker", "run", "--rm"]
     if os.path.exists(envutil.JOB_ENV_FILE):
         dockercmd.extend([f"--env-file={envutil.JOB_ENV_FILE}"])
 
+    # grab ssh config and keys for any git related work
+    dockercmd.extend([f"-v {os.path.expanduser('~')}/.ssh:/home/ci/.ssh"])
+
     quoted_script = quote_str_for_platform(script)
-    _docker_run_cmd_arg = f"/bin/bash -l -c {quoted_script}"
+    _docker_run_cmd_arg = f"/bin/bash -l -c -e {quoted_script}"
 
     dockercmd.extend(
         [
