@@ -14,6 +14,7 @@ import subprocess
 from datetime import datetime
 from operator import itemgetter
 from urllib.parse import urlparse
+import platform
 import requests
 import dotenv
 import click
@@ -162,15 +163,7 @@ def request_authorization():  # pylint: disable=too-many-locals
     env_path = pathlib.Path(".") / ".env"
     dotenv.load_dotenv(dotenv_path=env_path)
 
-    # Uncomment to connect to platform in dev environment
-    # todo: Need a make setting for switching between dev & prod env ticket: EO-473
-    # client_id = "6Sm3VSVQ15B9IxTFKmwrjcPzXaH0oC1P"
-    # base_url = "https://embedops-dev.us.auth0.com/oauth"
-
-    client_id = "wBgMNZyLb76QRZe3eDRsCnoBLBy4qMQh"
-    base_url = "https://embedops.us.auth0.com/oauth"
-
-    code_obj = request_user_code(client_id, base_url)
+    code_obj = request_user_code(settings.client_id, settings.base_url)
 
     # Request the user code and verification url, show instructions to user
     user_code = code_obj["user_code"]
@@ -181,20 +174,17 @@ def request_authorization():  # pylint: disable=too-many-locals
     verification_url = code_obj["verification_uri_complete"]
     device_code = code_obj["device_code"]
 
-    return launch_login_url(verification_url, base_url, device_code, client_id)
+    return launch_login_url(
+        verification_url, settings.base_url, device_code, settings.client_id
+    )
 
 
 def request_user_code(client_id, base_url):
     """Request the code to show to the user"""
     # We generate a nonce (state) that is used to protect against attackers invoking the callback
 
-    # Uncomment to connect to platform in dev environment
-    # todo: Need a make setting for switching between dev & prod env ticket: EO-473
-    # audience = "https://app-dev.embedops.com"
-    audience = "https://app.embedops.com"
-
     data = {
-        "audience": audience,
+        "audience": settings.audience,
         "scope": "openid email profile offline_access",
         "client_id": client_id,
     }
@@ -310,7 +300,8 @@ def docker_cli_login(aws_access_key_id, aws_secret_access_key):
     registry_token = base64.b64decode(authorization_token).decode().replace("AWS:", "")
     try:
         subprocess.check_output(
-            f"echo {registry_token} | \
+            ("powershell " if platform.system() == "Windows" else "")
+            + f"echo {registry_token} | \
                 docker login -u AWS --password-stdin {urlparse(registry_server).netloc}",
             shell=True,
             stderr=subprocess.DEVNULL,
